@@ -17,14 +17,18 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.*;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
 
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.permission.ResourcePermissionCheckService;
 import org.apache.dolphinscheduler.api.service.impl.AlertGroupServiceImpl;
+import org.apache.dolphinscheduler.api.service.impl.BaseServiceImpl;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
-import org.apache.dolphinscheduler.common.Constants;
+import org.apache.dolphinscheduler.common.constants.Constants;
+import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.dao.entity.AlertGroup;
 import org.apache.dolphinscheduler.dao.entity.User;
@@ -33,8 +37,10 @@ import org.apache.dolphinscheduler.dao.mapper.AlertGroupMapper;
 import org.apache.commons.collections.CollectionUtils;
 
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -42,6 +48,7 @@ import org.junit.runner.RunWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Mockito;
+import org.mockito.Spy;
 import org.mockito.junit.MockitoJUnitRunner;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -56,7 +63,9 @@ import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 @RunWith(MockitoJUnitRunner.class)
 public class AlertGroupServiceTest {
 
+    private static final Logger baseServiceLogger = LoggerFactory.getLogger(BaseServiceImpl.class);
     private static final Logger logger = LoggerFactory.getLogger(AlertGroupServiceTest.class);
+    private static final Logger alertGroupServiceLogger = LoggerFactory.getLogger(AlertGroupServiceImpl.class);
 
     @InjectMocks
     private AlertGroupServiceImpl alertGroupService;
@@ -66,11 +75,14 @@ public class AlertGroupServiceTest {
 
     private String groupName = "AlertGroupServiceTest";
 
+    @Spy
+    private ResourcePermissionCheckService resourcePermissionCheckService;
+
     @Test
     public void testQueryAlertGroup() {
 
         Mockito.when(alertGroupMapper.queryAllGroupList()).thenReturn(getList());
-        Map<String, Object> result = alertGroupService.queryAlertgroup();
+        Map<String, Object> result = alertGroupService.queryAlertgroup(getLoginUser());
         logger.info(result.toString());
         List<AlertGroup> alertGroups = (List<AlertGroup>) result.get(Constants.DATA_LIST);
         Assert.assertTrue(CollectionUtils.isNotEmpty(alertGroups));
@@ -84,11 +96,17 @@ public class AlertGroupServiceTest {
         Mockito.when(alertGroupMapper.queryAlertGroupPage(any(Page.class), eq(groupName))).thenReturn(page);
         User user = new User();
         // no operate
+        user.setUserType(UserType.GENERAL_USER);
+        user.setId(88);
+
+        Set<Integer> ids = new HashSet<>();
+        ids.add(1);
         Result result = alertGroupService.listPaging(user, groupName, 1, 10);
         logger.info(result.toString());
-        Assert.assertEquals(Status.USER_NO_OPERATION_PERM.getCode(), (int) result.getCode());
-        //success
+        Assert.assertEquals(Status.SUCCESS.getCode(), (int) result.getCode());
+        // success
         user.setUserType(UserType.ADMIN_USER);
+        user.setId(0);
         result = alertGroupService.listPaging(user, groupName, 1, 10);
         logger.info(result.toString());
         PageInfo<AlertGroup> pageInfo = (PageInfo<AlertGroup>) result.getData();
@@ -101,12 +119,19 @@ public class AlertGroupServiceTest {
 
         Mockito.when(alertGroupMapper.insert(any(AlertGroup.class))).thenReturn(2);
         User user = new User();
-        //no operate
+        user.setId(0);
+        // no operate
+        user.setUserType(UserType.GENERAL_USER);
         Map<String, Object> result = alertGroupService.createAlertgroup(user, groupName, groupName, null);
         logger.info(result.toString());
         Assert.assertEquals(Status.USER_NO_OPERATION_PERM, result.get(Constants.STATUS));
         user.setUserType(UserType.ADMIN_USER);
-        //success
+        user.setId(0);
+        // success
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), ALERT_GROUP_CREATE, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), baseServiceLogger)).thenReturn(true);
         result = alertGroupService.createAlertgroup(user, groupName, groupName, null);
         logger.info(result.toString());
         Assert.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
@@ -116,9 +141,15 @@ public class AlertGroupServiceTest {
     @Test
     public void testCreateAlertgroupDuplicate() {
 
-        Mockito.when(alertGroupMapper.insert(any(AlertGroup.class))).thenThrow(new DuplicateKeyException("group name exist"));
+        Mockito.when(alertGroupMapper.insert(any(AlertGroup.class)))
+                .thenThrow(new DuplicateKeyException("group name exist"));
         User user = new User();
         user.setUserType(UserType.ADMIN_USER);
+        user.setId(0);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), ALERT_GROUP_CREATE, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), baseServiceLogger)).thenReturn(true);
         Map<String, Object> result = alertGroupService.createAlertgroup(user, groupName, groupName, null);
         logger.info(result.toString());
         Assert.assertEquals(Status.ALERT_GROUP_EXIST, result.get(Constants.STATUS));
@@ -128,16 +159,25 @@ public class AlertGroupServiceTest {
     public void testUpdateAlertgroup() {
 
         User user = new User();
+        user.setId(0);
         // no operate
+        user.setUserType(UserType.GENERAL_USER);
         Map<String, Object> result = alertGroupService.updateAlertgroup(user, 1, groupName, groupName, null);
         logger.info(result.toString());
         Assert.assertEquals(Status.USER_NO_OPERATION_PERM, result.get(Constants.STATUS));
         user.setUserType(UserType.ADMIN_USER);
         // not exist
+        user.setUserType(UserType.ADMIN_USER);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), ALERT_GROUP_UPDATE, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.ALERT_GROUP,
+                new Object[]{1}, 0, baseServiceLogger)).thenReturn(true);
         result = alertGroupService.updateAlertgroup(user, 1, groupName, groupName, null);
         logger.info(result.toString());
         Assert.assertEquals(Status.ALERT_GROUP_NOT_EXIST, result.get(Constants.STATUS));
-        //success
+        // success
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.ALERT_GROUP,
+                new Object[]{2}, user.getId(), baseServiceLogger)).thenReturn(true);
         Mockito.when(alertGroupMapper.selectById(2)).thenReturn(getEntity());
         result = alertGroupService.updateAlertgroup(user, 2, groupName, groupName, null);
         logger.info(result.toString());
@@ -148,9 +188,15 @@ public class AlertGroupServiceTest {
     @Test
     public void testUpdateAlertgroupDuplicate() {
         User user = new User();
+        user.setId(0);
         user.setUserType(UserType.ADMIN_USER);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), ALERT_GROUP_UPDATE, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.ALERT_GROUP,
+                new Object[]{2}, user.getId(), baseServiceLogger)).thenReturn(true);
         Mockito.when(alertGroupMapper.selectById(2)).thenReturn(getEntity());
-        Mockito.when(alertGroupMapper.updateById(Mockito.any())).thenThrow(new DuplicateKeyException("group name exist"));
+        Mockito.when(alertGroupMapper.updateById(Mockito.any()))
+                .thenThrow(new DuplicateKeyException("group name exist"));
         Map<String, Object> result = alertGroupService.updateAlertgroup(user, 2, groupName, groupName, null);
         Assert.assertEquals(Status.ALERT_GROUP_EXIST, result.get(Constants.STATUS));
     }
@@ -159,16 +205,28 @@ public class AlertGroupServiceTest {
     public void testDelAlertgroupById() {
 
         User user = new User();
+        user.setId(0);
         // no operate
+        user.setUserType(UserType.GENERAL_USER);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), ALERT_GROUP_DELETE, baseServiceLogger)).thenReturn(true);
         Map<String, Object> result = alertGroupService.delAlertgroupById(user, 1);
         logger.info(result.toString());
         Assert.assertEquals(Status.USER_NO_OPERATION_PERM, result.get(Constants.STATUS));
-        user.setUserType(UserType.ADMIN_USER);
+
         // not exist
+        user.setUserType(UserType.ADMIN_USER);
+        user.setId(0);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.ALERT_GROUP, null,
+                user.getId(), ALERT_GROUP_DELETE, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.ALERT_GROUP,
+                new Object[]{2}, 0, baseServiceLogger)).thenReturn(true);
         result = alertGroupService.delAlertgroupById(user, 2);
         logger.info(result.toString());
         Assert.assertEquals(Status.ALERT_GROUP_NOT_EXIST, result.get(Constants.STATUS));
-        //success
+        // success
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.ALERT_GROUP,
+                new Object[]{2}, 0, baseServiceLogger)).thenReturn(true);
         Mockito.when(alertGroupMapper.selectById(2)).thenReturn(getEntity());
         result = alertGroupService.delAlertgroupById(user, 2);
         logger.info(result.toString());
@@ -178,12 +236,12 @@ public class AlertGroupServiceTest {
 
     @Test
     public void testVerifyGroupName() {
-        //group name not exist
+        // group name not exist
         boolean result = alertGroupService.existGroupName(groupName);
         Assert.assertFalse(result);
         Mockito.when(alertGroupMapper.existGroupName(groupName)).thenReturn(true);
 
-        //group name exist
+        // group name exist
         result = alertGroupService.existGroupName(groupName);
         Assert.assertTrue(result);
     }
@@ -213,7 +271,7 @@ public class AlertGroupServiceTest {
      */
     private AlertGroup getEntity() {
         AlertGroup alertGroup = new AlertGroup();
-        alertGroup.setId(1);
+        alertGroup.setId(0);
         alertGroup.setGroupName(groupName);
         return alertGroup;
     }
