@@ -21,10 +21,5 @@ package org.apache.dolphinscheduler.common.enums;
  * data base types
  */
 public enum ResUploadType {
-  /**
-   * 0 hdfs
-   * 1 s3
-   * 2 none
-   */
-  HDFS,S3,NONE
+    HDFS, S3, OSS, NONE
 }
