@@ -22,5 +22,5 @@ public enum TaskEventType {
     DELAY,
     RUNNING,
     RESULT,
-    ;
+    WORKER_REJECT
 }
