@@ -17,33 +17,33 @@
 
 package org.apache.dolphinscheduler.server.master.runner;
 
-import org.apache.dolphinscheduler.common.Constants;
+import lombok.NonNull;
+import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.StateEventType;
 import org.apache.dolphinscheduler.common.enums.TimeoutFlag;
+import org.apache.dolphinscheduler.common.lifecycle.ServerLifeCycleManager;
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionStatus;
 import org.apache.dolphinscheduler.common.thread.BaseDaemonThread;
-import org.apache.dolphinscheduler.common.thread.Stopper;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
-import org.apache.dolphinscheduler.common.utils.LoggerUtils;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
-import org.apache.dolphinscheduler.plugin.task.api.enums.ExecutionStatus;
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.apache.dolphinscheduler.server.master.cache.ProcessInstanceExecCacheManager;
 import org.apache.dolphinscheduler.server.master.config.MasterConfig;
-import org.apache.dolphinscheduler.server.master.event.StateEvent;
+import org.apache.dolphinscheduler.server.master.event.TaskStateEvent;
+import org.apache.dolphinscheduler.server.master.event.WorkflowStateEvent;
 import org.apache.dolphinscheduler.server.master.runner.task.TaskInstanceKey;
-
-import java.util.Optional;
-import java.util.concurrent.ConcurrentLinkedQueue;
-
-import javax.annotation.PostConstruct;
-
+import org.apache.dolphinscheduler.service.utils.LoggerUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.context.annotation.Lazy;
 import org.springframework.stereotype.Component;
 
-import lombok.NonNull;
+import javax.annotation.PostConstruct;
+import java.util.Optional;
+import java.util.concurrent.ConcurrentLinkedQueue;
 
 /**
  * Check thread
@@ -80,6 +80,7 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
     @Autowired
     private MasterConfig masterConfig;
 
+    @Lazy
     @Autowired
     private WorkflowExecuteThreadPool workflowExecuteThreadPool;
 
@@ -98,7 +99,7 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
     @Override
     public void run() {
         final long checkInterval = masterConfig.getStateWheelInterval().toMillis();
-        while (Stopper.isRunning()) {
+        while (!ServerLifeCycleManager.isStopped()) {
             try {
                 checkTask4Timeout();
                 checkTask4Retry();
@@ -119,13 +120,13 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
 
     public void addProcess4TimeoutCheck(ProcessInstance processInstance) {
         processInstanceTimeoutCheckList.add(processInstance.getId());
-        logger.info("Success add workflow instance into timeout check list");
+        logger.info("Success add workflow instance {} into timeout check list", processInstance.getId());
     }
 
     public void removeProcess4TimeoutCheck(int processInstanceId) {
         boolean removeFlag = processInstanceTimeoutCheckList.remove(processInstanceId);
         if (removeFlag) {
-            logger.info("Success remove workflow instance from timeout check list");
+            logger.info("Success remove workflow instance {} from timeout check list", processInstanceId);
         }
     }
 
@@ -137,10 +138,10 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
             try {
                 LoggerUtils.setWorkflowInstanceIdMDC(processInstanceId);
                 WorkflowExecuteRunnable workflowExecuteThread = processInstanceExecCacheManager.getByProcessInstanceId(
-                    processInstanceId);
+                        processInstanceId);
                 if (workflowExecuteThread == null) {
                     logger.warn(
-                        "Check workflow timeout failed, can not find workflowExecuteThread from cache manager, will remove this workflowInstance from check list");
+                            "Check workflow timeout failed, can not find workflowExecuteThread from cache manager, will remove this workflowInstance from check list");
                     processInstanceTimeoutCheckList.remove(processInstanceId);
                     continue;
                 }
@@ -150,10 +151,10 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
                     continue;
                 }
                 long timeRemain = DateUtils.getRemainTime(processInstance.getStartTime(),
-                                                          (long) processInstance.getTimeout()
-                                                              * Constants.SEC_2_MINUTES_TIME_UNIT);
+                        (long) processInstance.getTimeout()
+                                * Constants.SEC_2_MINUTES_TIME_UNIT);
                 if (timeRemain < 0) {
-                    logger.info("Workflow instance timeout, adding timeout event");
+                    logger.info("Workflow instance {} timeout, adding timeout event", processInstance.getId());
                     addProcessTimeoutEvent(processInstance);
                     processInstanceTimeoutCheckList.remove(processInstance.getId());
                     logger.info("Workflow instance timeout, added timeout event");
@@ -207,8 +208,8 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
             return;
         }
         taskInstanceRetryCheckList.add(taskInstanceKey);
-        logger.info("[WorkflowInstance-{}][TaskInstance-{}] Added task instance into retry check list",
-            processInstance.getId(), taskInstance.getId());
+        logger.info("[WorkflowInstance-{}][TaskInstanceKey-{}:{}] Added task instance into retry check list",
+                processInstance.getId(), taskInstance.getTaskCode(), taskInstance.getTaskDefinitionVersion());
     }
 
     public void removeTask4RetryCheck(@NonNull ProcessInstance processInstance, @NonNull TaskInstance taskInstance) {
@@ -236,6 +237,13 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
         logger.info("Removed task instance from state check list");
     }
 
+    public void clearAllTasks() {
+        processInstanceTimeoutCheckList.clear();
+        taskInstanceTimeoutCheckList.clear();
+        taskInstanceRetryCheckList.clear();
+        taskInstanceStateCheckList.clear();
+    }
+
     private void checkTask4Timeout() {
         if (taskInstanceTimeoutCheckList.isEmpty()) {
             return;
@@ -246,26 +254,29 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
                 LoggerUtils.setWorkflowInstanceIdMDC(processInstanceId);
                 long taskCode = taskInstanceKey.getTaskCode();
 
-                WorkflowExecuteRunnable workflowExecuteThread = processInstanceExecCacheManager.getByProcessInstanceId(processInstanceId);
+                WorkflowExecuteRunnable workflowExecuteThread =
+                        processInstanceExecCacheManager.getByProcessInstanceId(processInstanceId);
                 if (workflowExecuteThread == null) {
-                    logger.warn("Check task instance timeout failed, can not find workflowExecuteThread from cache manager, will remove this check task");
+                    logger.warn(
+                            "Check task instance timeout failed, can not find workflowExecuteThread from cache manager, will remove this check task");
                     taskInstanceTimeoutCheckList.remove(taskInstanceKey);
                     continue;
                 }
-                Optional<TaskInstance> taskInstanceOptional = workflowExecuteThread.getActiveTaskInstanceByTaskCode(taskCode);
+                Optional<TaskInstance> taskInstanceOptional =
+                        workflowExecuteThread.getActiveTaskInstanceByTaskCode(taskCode);
                 if (!taskInstanceOptional.isPresent()) {
                     logger.warn(
-                        "Check task instance timeout failed, can not get taskInstance from workflowExecuteThread, taskCode: {}"
-                            + "will remove this check task",
-                        taskCode);
+                            "Check task instance timeout failed, can not get taskInstance from workflowExecuteThread, taskCode: {}"
+                                    + "will remove this check task",
+                            taskCode);
                     taskInstanceTimeoutCheckList.remove(taskInstanceKey);
                     continue;
                 }
                 TaskInstance taskInstance = taskInstanceOptional.get();
                 if (TimeoutFlag.OPEN == taskInstance.getTaskDefine().getTimeoutFlag()) {
                     long timeRemain = DateUtils.getRemainTime(taskInstance.getStartTime(),
-                                                              (long) taskInstance.getTaskDefine().getTimeout()
-                                                                  * Constants.SEC_2_MINUTES_TIME_UNIT);
+                            (long) taskInstance.getTaskDefine().getTimeout()
+                                    * Constants.SEC_2_MINUTES_TIME_UNIT);
                     if (timeRemain < 0) {
                         logger.info("Task instance is timeout, adding task timeout event and remove the check");
                         addTaskTimeoutEvent(taskInstance);
@@ -291,21 +302,24 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
             try {
                 LoggerUtils.setWorkflowInstanceIdMDC(processInstanceId);
 
-                WorkflowExecuteRunnable workflowExecuteThread = processInstanceExecCacheManager.getByProcessInstanceId(processInstanceId);
+                WorkflowExecuteRunnable workflowExecuteThread =
+                        processInstanceExecCacheManager.getByProcessInstanceId(processInstanceId);
 
                 if (workflowExecuteThread == null) {
                     logger.warn(
-                        "Task instance retry check failed, can not find workflowExecuteThread from cache manager, "
-                            + "will remove this check task");
+                            "Task instance retry check failed, can not find workflowExecuteThread from cache manager, "
+                                    + "will remove this check task");
                     taskInstanceRetryCheckList.remove(taskInstanceKey);
                     continue;
                 }
 
-                Optional<TaskInstance> taskInstanceOptional = workflowExecuteThread.getRetryTaskInstanceByTaskCode(taskCode);
+                Optional<TaskInstance> taskInstanceOptional =
+                        workflowExecuteThread.getRetryTaskInstanceByTaskCode(taskCode);
                 ProcessInstance processInstance = workflowExecuteThread.getProcessInstance();
 
-                if (processInstance.getState() == ExecutionStatus.READY_STOP) {
-                    logger.warn("The process instance is ready to stop, will send process stop event and remove the check task");
+                if (processInstance.getState().isReadyStop()) {
+                    logger.warn(
+                            "The process instance is ready to stop, will send process stop event and remove the check task");
                     addProcessStopEvent(processInstance);
                     taskInstanceRetryCheckList.remove(taskInstanceKey);
                     break;
@@ -313,22 +327,24 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
 
                 if (!taskInstanceOptional.isPresent()) {
                     logger.warn(
-                        "Task instance retry check failed, can not find taskInstance from workflowExecuteThread, will remove this check");
+                            "Task instance retry check failed, can not find taskInstance from workflowExecuteThread, will remove this check");
                     taskInstanceRetryCheckList.remove(taskInstanceKey);
                     continue;
                 }
 
                 TaskInstance taskInstance = taskInstanceOptional.get();
-                // We check the status to avoid when we do worker failover we submit a failover task, this task may be resubmit by this
+                // We check the status to avoid when we do worker failover we submit a failover task, this task may be
+                // resubmit by this
                 // thread
-                if (taskInstance.getState() != ExecutionStatus.NEED_FAULT_TOLERANCE
-                    && taskInstance.retryTaskIntervalOverTime()) {
+                if (taskInstance.getState() != TaskExecutionStatus.NEED_FAULT_TOLERANCE
+                        && taskInstance.retryTaskIntervalOverTime()) {
                     // reset taskInstance endTime and state
-                    // todo relative funtion: TaskInstance.retryTaskIntervalOverTime, WorkflowExecuteThread.cloneRetryTaskInstance
-                    logger.info("[TaskInstance-{}]The task instance can retry, will retry this task instance",
-                                taskInstance.getId());
+                    // todo relative funtion: TaskInstance.retryTaskIntervalOverTime,
+                    // WorkflowExecuteThread.cloneRetryTaskInstance
+                    logger.info("[TaskInstanceKey-{}:{}]The task instance can retry, will retry this task instance",
+                            taskInstance.getTaskCode(), taskInstance.getTaskDefinitionVersion());
                     taskInstance.setEndTime(null);
-                    taskInstance.setState(ExecutionStatus.SUBMITTED_SUCCESS);
+                    taskInstance.setState(TaskExecutionStatus.SUBMITTED_SUCCESS);
 
                     addTaskRetryEvent(taskInstance);
                     taskInstanceRetryCheckList.remove(taskInstanceKey);
@@ -351,21 +367,24 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
 
             try {
                 LoggerUtils.setTaskInstanceIdMDC(processInstanceId);
-                WorkflowExecuteRunnable workflowExecuteThread = processInstanceExecCacheManager.getByProcessInstanceId(processInstanceId);
+                WorkflowExecuteRunnable workflowExecuteThread =
+                        processInstanceExecCacheManager.getByProcessInstanceId(processInstanceId);
                 if (workflowExecuteThread == null) {
-                    logger.warn("Task instance state check failed, can not find workflowExecuteThread from cache manager, will remove this check task");
+                    logger.warn(
+                            "Task instance state check failed, can not find workflowExecuteThread from cache manager, will remove this check task");
                     taskInstanceStateCheckList.remove(taskInstanceKey);
                     continue;
                 }
-                Optional<TaskInstance> taskInstanceOptional = workflowExecuteThread.getActiveTaskInstanceByTaskCode(taskCode);
+                Optional<TaskInstance> taskInstanceOptional =
+                        workflowExecuteThread.getActiveTaskInstanceByTaskCode(taskCode);
                 if (!taskInstanceOptional.isPresent()) {
                     logger.warn(
-                        "Task instance state check failed, can not find taskInstance from workflowExecuteThread, will remove this check event");
+                            "Task instance state check failed, can not find taskInstance from workflowExecuteThread, will remove this check event");
                     taskInstanceStateCheckList.remove(taskInstanceKey);
                     continue;
                 }
                 TaskInstance taskInstance = taskInstanceOptional.get();
-                if (taskInstance.getState().typeIsFinished()) {
+                if (taskInstance.getState().isFinished()) {
                     continue;
                 }
                 addTaskStateChangeEvent(taskInstance);
@@ -378,46 +397,50 @@ public class StateWheelExecuteThread extends BaseDaemonThread {
     }
 
     private void addTaskStateChangeEvent(TaskInstance taskInstance) {
-        StateEvent stateEvent = new StateEvent();
-        stateEvent.setType(StateEventType.TASK_STATE_CHANGE);
-        stateEvent.setProcessInstanceId(taskInstance.getProcessInstanceId());
-        stateEvent.setTaskInstanceId(taskInstance.getId());
-        stateEvent.setTaskCode(taskInstance.getTaskCode());
-        stateEvent.setExecutionStatus(ExecutionStatus.RUNNING_EXECUTION);
+        TaskStateEvent stateEvent = TaskStateEvent.builder()
+                .processInstanceId(taskInstance.getProcessInstanceId())
+                .taskInstanceId(taskInstance.getId())
+                .taskCode(taskInstance.getTaskCode())
+                .type(StateEventType.TASK_STATE_CHANGE)
+                .status(TaskExecutionStatus.RUNNING_EXECUTION)
+                .build();
         workflowExecuteThreadPool.submitStateEvent(stateEvent);
     }
 
     private void addProcessStopEvent(ProcessInstance processInstance) {
-        StateEvent stateEvent = new StateEvent();
-        stateEvent.setType(StateEventType.PROCESS_STATE_CHANGE);
-        stateEvent.setProcessInstanceId(processInstance.getId());
-        stateEvent.setExecutionStatus(ExecutionStatus.STOP);
+        WorkflowStateEvent stateEvent = WorkflowStateEvent.builder()
+                .processInstanceId(processInstance.getId())
+                .type(StateEventType.PROCESS_STATE_CHANGE)
+                .status(WorkflowExecutionStatus.STOP)
+                .build();
         workflowExecuteThreadPool.submitStateEvent(stateEvent);
     }
 
     private void addTaskRetryEvent(TaskInstance taskInstance) {
-        StateEvent stateEvent = new StateEvent();
-        stateEvent.setType(StateEventType.TASK_RETRY);
-        stateEvent.setProcessInstanceId(taskInstance.getProcessInstanceId());
-        stateEvent.setTaskInstanceId(taskInstance.getId());
-        stateEvent.setTaskCode(taskInstance.getTaskCode());
-        stateEvent.setExecutionStatus(ExecutionStatus.RUNNING_EXECUTION);
+        TaskStateEvent stateEvent = TaskStateEvent.builder()
+                .processInstanceId(taskInstance.getProcessInstanceId())
+                .taskCode(taskInstance.getTaskCode())
+                .status(TaskExecutionStatus.RUNNING_EXECUTION)
+                .type(StateEventType.TASK_RETRY)
+                .build();
         workflowExecuteThreadPool.submitStateEvent(stateEvent);
     }
 
     private void addTaskTimeoutEvent(TaskInstance taskInstance) {
-        StateEvent stateEvent = new StateEvent();
-        stateEvent.setType(StateEventType.TASK_TIMEOUT);
-        stateEvent.setProcessInstanceId(taskInstance.getProcessInstanceId());
-        stateEvent.setTaskInstanceId(taskInstance.getId());
-        stateEvent.setTaskCode(taskInstance.getTaskCode());
+        TaskStateEvent stateEvent = TaskStateEvent.builder()
+                .processInstanceId(taskInstance.getProcessInstanceId())
+                .taskInstanceId(taskInstance.getId())
+                .type(StateEventType.TASK_TIMEOUT)
+                .taskCode(taskInstance.getTaskCode())
+                .build();
         workflowExecuteThreadPool.submitStateEvent(stateEvent);
     }
 
     private void addProcessTimeoutEvent(ProcessInstance processInstance) {
-        StateEvent stateEvent = new StateEvent();
-        stateEvent.setType(StateEventType.PROCESS_TIMEOUT);
-        stateEvent.setProcessInstanceId(processInstance.getId());
+        WorkflowStateEvent stateEvent = WorkflowStateEvent.builder()
+                .processInstanceId(processInstance.getId())
+                .type(StateEventType.PROCESS_TIMEOUT)
+                .build();
         workflowExecuteThreadPool.submitStateEvent(stateEvent);
     }
 
