@@ -17,21 +17,24 @@
 
 package org.apache.dolphinscheduler.server.master.runner.task;
 
-import com.fasterxml.jackson.core.type.TypeReference;
-import com.google.auto.service.AutoService;
-import org.apache.commons.lang.StringUtils;
+import static org.apache.dolphinscheduler.common.constants.Constants.LOCAL_PARAMS;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_SUB_PROCESS;
+
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionStatus;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.common.utils.NetUtils;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.plugin.task.api.enums.Direct;
-import org.apache.dolphinscheduler.plugin.task.api.enums.ExecutionStatus;
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskTimeoutStrategy;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
-import org.apache.dolphinscheduler.remote.command.StateEventChangeCommand;
+import org.apache.dolphinscheduler.remote.command.WorkflowStateEventChangeCommand;
 import org.apache.dolphinscheduler.remote.processor.StateEventCallbackService;
 import org.apache.dolphinscheduler.remote.utils.Host;
-import org.apache.dolphinscheduler.server.utils.LogUtils;
 import org.apache.dolphinscheduler.service.bean.SpringApplicationContext;
+import org.apache.dolphinscheduler.service.utils.LogUtils;
+
+import org.apache.commons.lang3.StringUtils;
 
 import java.util.Date;
 import java.util.List;
@@ -40,8 +43,8 @@ import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.stream.Collectors;
 
-import static org.apache.dolphinscheduler.common.Constants.LOCAL_PARAMS;
-import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_SUB_PROCESS;
+import com.fasterxml.jackson.core.type.TypeReference;
+import com.google.auto.service.AutoService;
 
 /**
  * subtask processor
@@ -56,11 +59,13 @@ public class SubTaskProcessor extends BaseTaskProcessor {
      */
     private final Lock runLock = new ReentrantLock();
 
-    private StateEventCallbackService stateEventCallbackService = SpringApplicationContext.getBean(StateEventCallbackService.class);
+    private StateEventCallbackService stateEventCallbackService =
+            SpringApplicationContext.getBean(StateEventCallbackService.class);
 
     @Override
     public boolean submitTask() {
-        this.taskInstance = processService.submitTaskWithRetry(processInstance, taskInstance, maxRetryTimes, commitInterval);
+        this.taskInstance =
+                processService.submitTaskWithRetry(processInstance, taskInstance, maxRetryTimes, commitInterval);
 
         if (this.taskInstance == null) {
             return false;
@@ -93,6 +98,11 @@ public class SubTaskProcessor extends BaseTaskProcessor {
         return true;
     }
 
+    @Override
+    protected boolean resubmitTask() {
+        return true;
+    }
+
     @Override
     protected boolean dispatchTask() {
         return true;
@@ -117,9 +127,10 @@ public class SubTaskProcessor extends BaseTaskProcessor {
                 this.processInstance.getId(),
                 this.taskInstance.getId(),
                 subProcessInstance.getId(),
-                subProcessInstance.getState().getDescp());
-        if (subProcessInstance != null && subProcessInstance.getState().typeIsFinished()) {
-            taskInstance.setState(subProcessInstance.getState());
+                subProcessInstance.getState());
+        if (subProcessInstance != null && subProcessInstance.getState().isFinished()) {
+            // todo: check the status and transform
+            taskInstance.setState(TaskExecutionStatus.of(subProcessInstance.getState().getCode()));
             taskInstance.setEndTime(new Date());
             dealFinish();
             processService.saveTaskInstance(taskInstance);
@@ -135,20 +146,23 @@ public class SubTaskProcessor extends BaseTaskProcessor {
             String subProcessInstanceVarPool = subProcessInstance.getVarPool();
             if (StringUtils.isNotEmpty(subProcessInstanceVarPool)) {
                 List<Property> varPoolProperties = JSONUtils.toList(thisTaskInstanceVarPool, Property.class);
-                Map<String, Object> taskParams = JSONUtils.parseObject(taskInstance.getTaskParams(), new TypeReference<Map<String, Object>>() {
-                });
+                Map<String, Object> taskParams =
+                        JSONUtils.parseObject(taskInstance.getTaskParams(), new TypeReference<Map<String, Object>>() {
+                        });
                 Object localParams = taskParams.get(LOCAL_PARAMS);
                 if (localParams != null) {
                     List<Property> properties = JSONUtils.toList(JSONUtils.toJsonString(localParams), Property.class);
-                    Map<String, String> subProcessParam = JSONUtils.toList(subProcessInstanceVarPool, Property.class).stream()
-                            .collect(Collectors.toMap(Property::getProp, Property::getValue));
-                    List<Property> outProperties = properties.stream().filter(r -> Direct.OUT == r.getDirect()).collect(Collectors.toList());
+                    Map<String, String> subProcessParam =
+                            JSONUtils.toList(subProcessInstanceVarPool, Property.class).stream()
+                                    .collect(Collectors.toMap(Property::getProp, Property::getValue));
+                    List<Property> outProperties =
+                            properties.stream().filter(r -> Direct.OUT == r.getDirect()).collect(Collectors.toList());
                     for (Property info : outProperties) {
                         info.setValue(subProcessParam.get(info.getProp()));
                         varPoolProperties.add(info);
                     }
                     taskInstance.setVarPool(JSONUtils.toJsonString(varPoolProperties));
-                    //deal with localParam for show in the page
+                    // deal with localParam for show in the page
                     processService.changeOutParam(taskInstance);
                 }
             }
@@ -162,12 +176,13 @@ public class SubTaskProcessor extends BaseTaskProcessor {
     }
 
     private boolean pauseSubWorkFlow() {
-        ProcessInstance subProcessInstance = processService.findSubProcessInstance(processInstance.getId(), taskInstance.getId());
-        if (subProcessInstance == null || taskInstance.getState().typeIsFinished() || subProcessInstance.getState().typeIsFinished()) {
+        ProcessInstance subProcessInstance =
+                processService.findSubProcessInstance(processInstance.getId(), taskInstance.getId());
+        if (subProcessInstance == null || taskInstance.getState().isFinished()) {
             return false;
         }
-        subProcessInstance.setState(ExecutionStatus.READY_PAUSE);
-        processService.updateProcessInstance(subProcessInstance);
+        subProcessInstance.setStateWithDesc(WorkflowExecutionStatus.READY_PAUSE, "ready pause sub workflow");
+        processInstanceDao.updateProcessInstance(subProcessInstance);
         sendToSubProcess();
         return true;
     }
@@ -180,11 +195,11 @@ public class SubTaskProcessor extends BaseTaskProcessor {
             return true;
         }
         subProcessInstance = processService.findSubProcessInstance(processInstance.getId(), taskInstance.getId());
-        if (subProcessInstance == null || taskInstance.getState().typeIsFinished()) {
+        if (subProcessInstance == null || taskInstance.getState().isFinished()) {
             return false;
         }
         taskInstance.setHost(NetUtils.getAddr(masterConfig.getListenPort()));
-        taskInstance.setState(ExecutionStatus.RUNNING_EXECUTION);
+        taskInstance.setState(TaskExecutionStatus.RUNNING_EXECUTION);
         taskInstance.setStartTime(new Date());
         processService.updateTaskInstance(taskInstance);
         logger.info("set sub work flow {} task {} state: {}",
@@ -197,21 +212,23 @@ public class SubTaskProcessor extends BaseTaskProcessor {
 
     @Override
     protected boolean killTask() {
-        ProcessInstance subProcessInstance = processService.findSubProcessInstance(processInstance.getId(), taskInstance.getId());
-        if (subProcessInstance == null || taskInstance.getState().typeIsFinished() || subProcessInstance.getState().typeIsFinished()) {
+        ProcessInstance subProcessInstance =
+                processService.findSubProcessInstance(processInstance.getId(), taskInstance.getId());
+        if (subProcessInstance == null || taskInstance.getState().isFinished()) {
             return false;
         }
-        subProcessInstance.setState(ExecutionStatus.READY_STOP);
-        processService.updateProcessInstance(subProcessInstance);
+        subProcessInstance.setStateWithDesc(WorkflowExecutionStatus.READY_STOP, "ready stop by kill task");
+        processInstanceDao.updateProcessInstance(subProcessInstance);
         sendToSubProcess();
         return true;
     }
 
     private void sendToSubProcess() {
-        StateEventChangeCommand stateEventChangeCommand = new StateEventChangeCommand(
-                processInstance.getId(), taskInstance.getId(), subProcessInstance.getState(), subProcessInstance.getId(), 0
-        );
-        this.stateEventCallbackService.sendResult(new Host(subProcessInstance.getHost()), stateEventChangeCommand.convert2Command());
+        WorkflowStateEventChangeCommand workflowStateEventChangeCommand = new WorkflowStateEventChangeCommand(
+                processInstance.getId(), taskInstance.getId(), subProcessInstance.getState(),
+                subProcessInstance.getId(), 0);
+        Host host = new Host(subProcessInstance.getHost());
+        this.stateEventCallbackService.sendResult(host, workflowStateEventChangeCommand.convert2Command());
     }
 
     @Override
