@@ -17,14 +17,15 @@
 
 package org.apache.dolphinscheduler.plugin.task.api.model;
 
-/**
- * resource info
- */
+import lombok.Data;
+
+@Data
 public class ResourceInfo {
+
     /**
      * res the name of the resource that was uploaded
      */
-    private int id;
+    private Integer id;
 
     /**
      * full name of the resource that was uploaded
@@ -32,28 +33,4 @@ public class ResourceInfo {
     private String resourceName;
 
     private String res;
-
-    public int getId() {
-        return id;
-    }
-
-    public void setId(int id) {
-        this.id = id;
-    }
-
-    public String getRes() {
-        return res;
-    }
-
-    public void setRes(String res) {
-        this.res = res;
-    }
-
-    public String getResourceName() {
-        return resourceName;
-    }
-
-    public void setResourceName(String resourceName) {
-        this.resourceName = resourceName;
-    }
 }
