@@ -39,8 +39,13 @@ public class FlinkConstants {
     /**
      * flink run options
      */
+    public static final String FLINK_RUN_APPLICATION = "run-application";
     public static final String FLINK_YARN_CLUSTER = "yarn-cluster";
+    public static final String FLINK_YARN_APPLICATION = "yarn-application";
+    public static final String FLINK_YARN_PER_JOB = "yarn-per-job";
+    public static final String FLINK_LOCAL = "local";
     public static final String FLINK_RUN_MODE = "-m";
+    public static final String FLINK_EXECUTION_TARGET = "-t";
     public static final String FLINK_YARN_SLOT = "-ys";
     public static final String FLINK_APP_NAME = "-ynm";
     public static final String FLINK_QUEUE = "-yqu";
@@ -51,7 +56,12 @@ public class FlinkConstants {
     public static final String FLINK_PARALLELISM = "-p";
     public static final String FLINK_SHUTDOWN_ON_ATTACHED_EXIT = "-sae";
     public static final String FLINK_PYTHON = "-py";
-
+    public static final String FLINK_SAVEPOINT = "savepoint";
+    public static final String FLINK_METRICS = "metrics";
+    public static final String FLINK_OVERVIEW = "overview";
+    public static final String FLINK_JOBS = "jobs";
+    public static final String FLINK_CANCEL = "cancel";
+    // For Flink SQL
     public static final String FLINK_FORMAT_EXECUTION_TARGET = "set execution.target=%s";
     public static final String FLINK_FORMAT_YARN_APPLICATION_NAME = "set yarn.application.name=%s";
     public static final String FLINK_FORMAT_YARN_APPLICATION_QUEUE = "set yarn.application.queue=%s";
@@ -62,12 +72,4 @@ public class FlinkConstants {
     public static final String FLINK_SQL_SCRIPT_FILE = "-f";
     public static final String FLINK_SQL_INIT_FILE = "-i";
     public static final String FLINK_SQL_NEWLINE = ";\n";
-
-    // execution.target options
-    public static final String EXECUTION_TARGET_YARN_PER_JOB = "yarn-per-job";
-    public static final String EXECUTION_TARGET_LOACL = "local";
-
-    public static final String DEPLOY_MODE_CLUSTER = "cluster";
-    public static final String DEPLOY_MODE_LOCAL = "local";
-    public static final String FLINK_VERSION_BEFORE_1_10 = "<1.10";
 }
