@@ -91,6 +91,10 @@ export default {
     next_five_execution_times: 'Next five execution times',
     execute_time: 'Execute time',
     failure_strategy: 'Failure Strategy',
+    node_execution: 'Node Execution',
+    backward_execution: 'Backward execution',
+    forward_execution: 'Forward execution',
+    current_node_execution: 'Execute only the current node',
     notification_strategy: 'Notification Strategy',
     workflow_priority: 'Workflow Priority',
     worker_group: 'Worker Group',
@@ -107,6 +111,11 @@ export default {
     all_send: 'All',
     whether_complement_data: 'Whether it is a complement process?',
     schedule_date: 'Schedule date',
+    select_date: 'Select Date',
+    enter_date: 'Enter Date',
+    schedule_date_tips:
+      'The format is yyyy-MM-dd HH:mm:ss with multiple comma splits',
+    schedule_date_limit: 'Enter more than 100 dates',
     mode_of_execution: 'Mode of execution',
     serial_execution: 'Serial execution',
     parallel_execution: 'Parallel execution',
@@ -191,7 +200,9 @@ export default {
     workflow_relation_no_data_result_title:
       'Can not find any relations of workflows.',
     workflow_relation_no_data_result_desc:
-      'There is not any workflows. Please create a workflow, and then visit this page again.'
+      'There is not any workflows. Please create a workflow, and then visit this page again.',
+    ready_to_block: 'Ready to block',
+    block: 'Block',
   },
   task: {
     cancel_full_screen: 'Cancel full screen',
@@ -232,7 +243,27 @@ export default {
     forced_success: 'Forced Success',
     view_log: 'View Log',
     download_log: 'Download Log',
-    refresh: 'Refresh'
+    refresh: 'Refresh',
+    app_id: 'Application ID',
+    execute: 'Execute',
+    stop: 'Stop',
+    batch_task: 'Batch Task',
+    stream_task: 'Stream Task',
+    jump_tip: 'Jump, not open yet!',
+    savepoint: 'Savepoint',
+    success: 'Success',
+    none_send: 'None',
+    success_send: 'Success',
+    failure_send: 'Failure',
+    all_send: 'All',
+    set_parameters_before_starting: 'Please set the parameters before starting',
+    notification_strategy: 'Notification Strategy',
+    worker_group: 'Worker group',
+    environment_name: 'Environment Name',
+    alarm_group: 'Alarm group',
+    startup_parameter: 'Startup Parameter',
+    whether_dry_run: 'Whether Dry-Run',
+    please_choose: 'Please Choose'
   },
   dag: {
     create: 'Create Workflow',
@@ -309,10 +340,20 @@ export default {
     task_group_name: 'Task group name',
     task_group_queue_priority: 'Priority',
     number_of_failed_retries: 'Number of failed retries',
+    cpu_quota: 'CPU quota',
+    memory_max: 'Max memory',
     times: 'Times',
     failed_retry_interval: 'Failed retry interval',
     minute: 'Minute',
     delay_execution_time: 'Delay execution time',
+    namespace_cluster: 'Namespace(Cluster)',
+    min_cpu: 'Min cpu',
+    min_memory: 'Min memory',
+    cores: 'Cores',
+    mb: 'MB',
+    image: 'Image',
+    image_tips: 'Please enter image',
+    min_memory_tips: 'Please enter min memory',
     state: 'State',
     branch_flow: 'Branch flow',
     cancel: 'Cancel',
@@ -338,6 +379,7 @@ export default {
     init_script_tips: 'Please enter initialization script',
     resources: 'Resources',
     resources_tips: 'Please select resources',
+    resources_limit_tips: 'Please select again, resource limit:',
     non_resources_tips: 'Please delete all non-existent resources',
     useless_resources_tips: 'Unauthorized or deleted resources',
     custom_parameters: 'Custom Parameters',
@@ -482,6 +524,8 @@ export default {
     allow_insert: 'AllowInsert',
     concurrency: 'Concurrency',
     concurrency_tips: 'Please enter Concurrency',
+    concurrency_column: 'Concurrency Column',
+    concurrency_column_tips: 'Please enter Concurrency Column',
     sea_tunnel_master: 'Master',
     sea_tunnel_master_url: 'Master URL',
     sea_tunnel_queue: 'Queue',
@@ -510,6 +554,7 @@ export default {
     datax_job_runtime_memory_xms: 'Low Limit Value',
     datax_job_runtime_memory_xmx: 'High Limit Value',
     datax_job_runtime_memory_unit: 'G',
+    chunjun_json_template: 'JSON script',
     current_hour: 'CurrentHour',
     last_1_hour: 'Last1Hour',
     last_2_hour: 'Last2Hours',
@@ -593,8 +638,103 @@ export default {
     required: 'required',
     emr_flow_define_json: 'jobFlowDefineJson',
     emr_flow_define_json_tips: 'Please enter the definition of the job flow.',
+    emr_steps_define_json: 'stepsDefineJson',
+    emr_steps_define_json_tips: 'Please enter the definition of the emr step.',
     segment_separator: 'Segment Execution Separator',
     segment_separator_tips: 'Please enter the segment execution separator',
+    zeppelin_note_id: 'zeppelinNoteId',
+    zeppelin_note_id_tips: 'Please enter the note id of your zeppelin note',
+    zeppelin_paragraph_id: 'zeppelinParagraphId',
+    zeppelin_paragraph_id_tips:
+      'Please enter the paragraph id of your zeppelin paragraph',
+    zeppelin_parameters: 'parameters',
+    zeppelin_parameters_tips:
+      'Please enter the parameters for zeppelin dynamic form',
+    zeppelin_rest_endpoint: 'zeppelinRestEndpoint',
+    zeppelin_rest_endpoint_tips:
+      'Please enter the rest endpoint of your Zeppelin server',
+    zeppelin_production_note_directory:
+      'Directory for cloned zeppelin note in production mode',
+    zeppelin_production_note_directory_tips:
+      'Please enter the production note directory to enable production mode',
+    hive_cli_task_execution_type: 'Hive Cli Task Execution Type',
+    hive_sql_script: 'Hive SQL Script',
+    hive_cli_options: 'Hive Cli Options',
+    hive_cli_options_tips:
+      'Please enter the options for hive cli, e.g. --verbose',
+    jupyter_conda_env_name: 'condaEnvName',
+    jupyter_conda_env_name_tips:
+      'Please enter the conda environment name of papermill',
+    jupyter_input_note_path: 'inputNotePath',
+    jupyter_input_note_path_tips: 'Please enter the input jupyter note path',
+    jupyter_output_note_path: 'outputNotePath',
+    jupyter_output_note_path_tips: 'Please enter the output jupyter note path',
+    jupyter_parameters: 'parameters',
+    jupyter_parameters_tips:
+      'Please enter the parameters for jupyter parameterization',
+    jupyter_kernel: 'kernel',
+    jupyter_kernel_tips: 'Please enter the jupyter kernel name',
+    jupyter_engine: 'engine',
+    jupyter_engine_tips: 'Please enter the engine name',
+    jupyter_execution_timeout: 'executionTimeout',
+    jupyter_execution_timeout_tips:
+      'Please enter the execution timeout for each jupyter note cell',
+    jupyter_start_timeout: 'startTimeout',
+    jupyter_start_timeout_tips:
+      'Please enter the start timeout for jupyter kernel',
+    jupyter_others: 'others',
+    jupyter_others_tips:
+      'Please enter the other options you need for papermill',
+    mlflow_algorithm: 'Algorithm',
+    mlflow_algorithm_tips: 'svm',
+    mlflow_params: 'Parameters',
+    mlflow_params_tips: ' ',
+    mlflow_searchParams: 'Parameter Search Space',
+    mlflow_searchParams_tips: ' ',
+    mlflow_isSearchParams: 'Search Parameters',
+    mlflow_dataPath: 'Data Path',
+    mlflow_dataPath_tips:
+      ' The absolute path of the file or folder. Ends with .csv for file or contain train.csv and test.csv for folder',
+    mlflow_dataPath_error_tips: ' data data can not be empty ',
+    mlflow_experimentName: 'Experiment Name',
+    mlflow_experimentName_tips: 'experiment_001',
+    mlflow_registerModel: 'Register Model',
+    mlflow_modelName: 'Model Name',
+    mlflow_modelName_tips: 'model_001',
+    mlflow_mlflowTrackingUri: 'MLflow Tracking Server URI',
+    mlflow_mlflowTrackingUri_tips: 'http://127.0.0.1:5000',
+    mlflow_mlflowTrackingUri_error_tips:
+      'MLflow Tracking Server URI can not be empty',
+    mlflow_jobType: 'Job Type',
+    mlflow_automlTool: 'AutoML Tool',
+    mlflow_taskType: 'MLflow Task Type',
+    mlflow_deployType: 'Deploy Mode',
+    mlflow_deployModelKey: 'Model-URI',
+    mlflow_deployPort: 'Port',
+    mlflowProjectRepository: 'Repository',
+    mlflowProjectRepository_tips: 'git respository or path on worker',
+    mlflowProjectVersion: 'Project Version',
+    mlflowProjectVersion_tips: 'git version',
+    mlflow_cpuLimit: 'Max Cpu Limit',
+    mlflow_memoryLimit: 'Max Memory Limit',
+    openmldb_zk_address: 'zookeeper address',
+    openmldb_zk_address_tips: 'Please enter the zookeeper address',
+    openmldb_zk_path: 'zookeeper path',
+    openmldb_zk_path_tips: 'Please enter the zookeeper path',
+    openmldb_execute_mode: 'Execute Mode',
+    openmldb_execute_mode_tips: 'Please select the execute mode',
+    openmldb_execute_mode_offline: 'offline',
+    openmldb_execute_mode_online: 'online',
+    dvc_task_type: 'DVC Task Type',
+    dvc_repository: 'DVC Repository',
+    dvc_repository_tips: 'please input the url of dvc repository',
+    dvc_version: 'Version',
+    dvc_version_tips: 'data version, will be mark as git tag',
+    dvc_data_location: 'Data Path in DVC Repository',
+    dvc_message: 'Version Message',
+    dvc_load_save_data_path: 'Data Path In Worker',
+    dvc_store_url: 'Store Url',
+    dvc_empty_tips: 'This parameter cannot be empty',
     send_email: 'Send Email',
     log_display: 'Log display',
     rows_of_result: 'rows of result',
@@ -615,6 +755,27 @@ export default {
       'Please select column, only single column is supported',
     please_enter_threshold_number_is_needed:
       'Please enter threshold number is needed',
-    please_enter_comparison_title: 'please select comparison title'
+    please_enter_comparison_title: 'please select comparison title',
+    custom_config: 'Custom Config',
+    engine: 'engine',
+    engine_tips: 'Please select engine',
+    run_mode: 'Run Mode',
+    dinky_address: 'Dinky address',
+    dinky_address_tips: 'Please enter the url of your dinky',
+    dinky_task_id: 'Dinky task id',
+    dinky_task_id_tips: 'Please enter the task id of your dinky',
+    dinky_online: 'Online task',
+    pytorch_script: 'Python Script',
+    pytorch_script_params: 'Script Input Parameters',
+    pytorch_other_params: 'Show More Configurations',
+    pytorch_python_path: 'Project Path',
+    pytorch_is_create_environment: 'Create An Environment Or Not',
+    pytorch_python_command: 'Python Command Path',
+    pytorch_python_command_tips: 'If empty，will be set $PYTHON_HOME',
+    pytorch_python_env_tool: 'Python Environment Manager Tool',
+    pytorch_requirements: 'Requirement File',
+    pytorch_conda_python_version: 'Python Version',
+    pytorch_conda_python_version_tips:
+      'Please enter the version number, such as 3.6, 3.7, 3.x'
   }
 }
