@@ -93,6 +93,10 @@ export default {
     next_five_execution_times: '接下来五次执行时间',
     execute_time: '执行时间',
     failure_strategy: '失败策略',
+    node_execution: '节点执行',
+    backward_execution: '向后执行',
+    forward_execution: '向前执行',
+    current_node_execution: '仅执行当前节点',
     notification_strategy: '通知策略',
     workflow_priority: '流程优先级',
     worker_group: 'Worker分组',
@@ -109,6 +113,10 @@ export default {
     all_send: '成功或失败都发',
     whether_complement_data: '是否是补数',
     schedule_date: '调度日期',
+    select_date: '日期选择',
+    enter_date: '手动输入',
+    schedule_date_tips: '格式为yyyy-MM-dd HH:mm:ss，多个逗号分割',
+    schedule_date_limit: '输入日期不满足<=100条',
     mode_of_execution: '执行方式',
     serial_execution: '串行执行',
     parallel_execution: '并行执行',
@@ -192,7 +200,9 @@ export default {
     project_tips: '请选择项目',
     workflow_relation_no_data_result_title: '工作流关系不存在',
     workflow_relation_no_data_result_desc:
-      '目前没有任何工作流，请先创建工作流，再访问该页面'
+      '目前没有任何工作流，请先创建工作流，再访问该页面',
+    ready_to_block: '准备锁定',
+    block: '锁定',
   },
   task: {
     cancel_full_screen: '取消全屏',
@@ -202,6 +212,7 @@ export default {
     offline: '已下线',
     task_name: '任务名称',
     task_type: '任务类型',
+    task_instance: '任务实例',
     create_task: '创建任务',
     workflow_instance: '工作流实例',
     workflow_name: '工作流名称',
@@ -233,7 +244,27 @@ export default {
     forced_success: '强制成功',
     view_log: '查看日志',
     download_log: '下载日志',
-    refresh: '刷新'
+    refresh: '刷新',
+    app_id: 'Application ID',
+    execute: '执行',
+    stop: '停止',
+    batch_task: '批量任务',
+    stream_task: '实时任务',
+    jump_tip: '跳转，暂未开放!',
+    savepoint: 'Savepoint',
+    success: '成功',
+    none_send: '都不发',
+    success_send: '成功发',
+    failure_send: '失败发',
+    all_send: '成功或失败都发',
+    set_parameters_before_starting: '启动前请先设置参数',
+    notification_strategy: '通知策略',
+    worker_group: 'Worker分组',
+    environment_name: '环境名称',
+    alarm_group: '告警组',
+    startup_parameter: '启动参数',
+    whether_dry_run: '是否空跑',
+    please_choose: '请选择'
   },
   dag: {
     create: '创建工作流',
@@ -309,10 +340,20 @@ export default {
     task_group_name: '任务组名称',
     task_group_queue_priority: '组内优先级',
     number_of_failed_retries: '失败重试次数',
+    cpu_quota: 'CPU配额',
+    memory_max: '最大内存',
     times: '次',
     failed_retry_interval: '失败重试间隔',
     minute: '分',
     delay_execution_time: '延时执行时间',
+    namespace_cluster: '命名空间(集群)',
+    min_cpu: '最小cpu',
+    min_memory: '最小内存',
+    cores: '核',
+    mb: 'MB',
+    image: '镜像',
+    image_tips: '请输入镜像',
+    min_memory_tips: '请输入最小内存',
     state: '状态',
     branch_flow: '分支流转',
     cancel: '取消',
@@ -335,6 +376,7 @@ export default {
     init_script_tips: '请输入初始化脚本',
     resources: '资源',
     resources_tips: '请选择资源',
+    resources_limit_tips: '请重新选择，资源个数限制:',
     no_resources_tips: '请删除所有未授权或已删除资源',
     useless_resources_tips: '未授权或已删除资源',
     custom_parameters: '自定义参数',
@@ -477,6 +519,8 @@ export default {
     allow_insert: '无更新便插入',
     concurrency: '并发度',
     concurrency_tips: '请输入并发度',
+    concurrency_column: '并发键',
+    concurrency_column_tips: '请输入并发键',
     sea_tunnel_master: 'Master',
     sea_tunnel_master_url: 'Master URL',
     sea_tunnel_queue: '队列',
@@ -504,6 +548,7 @@ export default {
     datax_job_runtime_memory_xms: '最小内存',
     datax_job_runtime_memory_xmx: '最大内存',
     datax_job_runtime_memory_unit: 'G',
+    chunjun_json_template: 'JSON 脚本',
     current_hour: '当前小时',
     last_1_hour: '前1小时',
     last_2_hour: '前2小时',
@@ -587,8 +632,92 @@ export default {
     required: '必填',
     emr_flow_define_json: 'jobFlowDefineJson',
     emr_flow_define_json_tips: '请输入工作流定义',
+    emr_steps_define_json: 'stepsDefineJson',
+    emr_steps_define_json_tips: '请输入EMR步骤定义',
     segment_separator: '分段执行符号',
     segment_separator_tips: '请输入分段执行符号',
+    zeppelin_note_id: 'zeppelinNoteId',
+    zeppelin_note_id_tips: '请输入zeppelin note id',
+    zeppelin_paragraph_id: 'zeppelinParagraphId',
+    zeppelin_production_note_directory: '生产模式下存放克隆note的目录',
+    zeppelin_production_note_directory_tips:
+      '请输入生产环境note目录以启用生产模式',
+    zeppelin_paragraph_id_tips: '请输入zeppelin paragraph id',
+    zeppelin_parameters: 'parameters',
+    zeppelin_parameters_tips: '请输入zeppelin dynamic form参数',
+    zeppelin_rest_endpoint: 'zeppelinRestEndpoint',
+    zeppelin_rest_endpoint_tips: '请输入zeppelin server的rest endpoint',
+    hive_cli_task_execution_type: 'Hive Cli 任务类型',
+    hive_sql_script: 'Hive SQL 脚本',
+    hive_cli_options: 'Hive Cli 选项',
+    hive_cli_options_tips: '请输入您的Hive Cli选项，如--verbose等',
+    jupyter_conda_env_name: 'condaEnvName',
+    jupyter_conda_env_name_tips: '请输入papermill所在的conda环境名',
+    jupyter_input_note_path: 'inputNotePath',
+    jupyter_input_note_path_tips: '请输入jupyter note的输入路径',
+    jupyter_output_note_path: 'outputNotePath',
+    jupyter_output_note_path_tips: '请输入jupyter note的输出路径',
+    jupyter_parameters: 'parameters',
+    jupyter_parameters_tips: '请输入jupyter parameterization参数',
+    jupyter_kernel: 'kernel',
+    jupyter_kernel_tips: '请输入jupyter kernel名',
+    jupyter_engine: 'engine',
+    jupyter_engine_tips: '请输入引擎名称',
+    jupyter_execution_timeout: 'executionTimeout',
+    jupyter_execution_timeout_tips: '请输入jupyter note cell的执行最长时间',
+    jupyter_start_timeout: 'startTimeout',
+    jupyter_start_timeout_tips: '请输入jupyter kernel的启动最长时间',
+    jupyter_others: 'others',
+    jupyter_others_tips: '请输入papermill的其他参数',
+    mlflow_algorithm: '算法',
+    mlflow_algorithm_tips: 'svm',
+    mlflow_params: '参数',
+    mlflow_params_tips: ' ',
+    mlflow_searchParams: '参数搜索空间',
+    mlflow_searchParams_tips: ' ',
+    mlflow_isSearchParams: '是否搜索参数',
+    mlflow_dataPath: '数据路径',
+    mlflow_dataPath_tips:
+      ' 文件/文件夹的绝对路径, 若文件需以.csv结尾, 文件夹需包含train.csv和test.csv ',
+    mlflow_dataPath_error_tips: ' 数据路径不能为空 ',
+    mlflow_experimentName: '实验名称',
+    mlflow_experimentName_tips: 'experiment_001',
+    mlflow_registerModel: '注册模型',
+    mlflow_modelName: '注册的模型名称',
+    mlflow_modelName_tips: 'model_001',
+    mlflow_mlflowTrackingUri: 'MLflow Tracking Server URI',
+    mlflow_mlflowTrackingUri_tips: 'http://127.0.0.1:5000',
+    mlflow_mlflowTrackingUri_error_tips: ' MLflow Tracking Server URI 不能为空',
+    mlflow_jobType: '任务类型',
+    mlflow_automlTool: 'AutoML工具',
+    mlflow_taskType: 'MLflow 任务类型',
+    mlflow_deployType: '部署类型',
+    mlflow_deployModelKey: '部署的模型URI',
+    mlflow_deployPort: '监听端口',
+    mlflowProjectRepository: '运行仓库',
+    mlflowProjectRepository_tips: '可以为git仓库或worker上的路径',
+    mlflowProjectVersion: '项目版本',
+    mlflowProjectVersion_tips: '项目git版本',
+    mlflow_cpuLimit: '最大cpu限制',
+    mlflow_memoryLimit: '最大内存限制',
+    openmldb_zk_address: 'zookeeper地址',
+    openmldb_zk_address_tips: '请输入zookeeper地址',
+    openmldb_zk_path: 'zookeeper路径',
+    openmldb_zk_path_tips: '请输入zookeeper路径',
+    openmldb_execute_mode: '执行模式',
+    openmldb_execute_mode_tips: '请选择执行模式',
+    openmldb_execute_mode_offline: '离线',
+    openmldb_execute_mode_online: '在线',
+    dvc_task_type: 'DVC任务类型',
+    dvc_repository: 'DVC仓库',
+    dvc_repository_tips: '请输入DVC仓库地址',
+    dvc_version: '数据版本',
+    dvc_version_tips: '数据版本标识，会以git tag的形式标记',
+    dvc_data_location: 'DVC仓库中的数据路径',
+    dvc_message: '提交信息',
+    dvc_load_save_data_path: 'Worker中数据路径',
+    dvc_store_url: '数据存储地址',
+    dvc_empty_tips: '该参数不能为空',
     send_email: '发送邮件',
     log_display: '日志显示',
     rows_of_result: '行查询结果',
@@ -607,6 +736,26 @@ export default {
     please_enter_filter_expression: '请输入源表过滤条件',
     please_enter_column_only_single_column_is_supported: '请选择源表检测列',
     please_enter_threshold_number_is_needed: '请输入阈值',
-    please_enter_comparison_title: '请选择期望值类型'
+    please_enter_comparison_title: '请选择期望值类型',
+    custom_config: '自定义配置',
+    engine: '引擎',
+    engine_tips: '请选择引擎',
+    run_mode: '运行模式',
+    dinky_address: 'dinky 地址',
+    dinky_address_tips: '请输入 Dinky 地址',
+    dinky_task_id: 'dinky 作业ID',
+    dinky_task_id_tips: '请输入作业 ID',
+    dinky_online: '是否上线作业',
+    pytorch_script: 'python脚本',
+    pytorch_script_params: '脚本启动参数',
+    pytorch_other_params: '展开更多配置',
+    pytorch_python_path: 'python项目地址',
+    pytorch_is_create_environment: '是否创建新环境',
+    pytorch_python_command: 'python命令路径',
+    pytorch_python_command_tips: '若为空，则使用$PYTHON_HOME',
+    pytorch_python_env_tool: 'python环境管理工具',
+    pytorch_requirements: '依赖文件',
+    pytorch_conda_python_version: 'python版本',
+    pytorch_conda_python_version_tips: '请输入版本号，如 3.6, 3.7, 3.x等'
   }
 }
