@@ -16,7 +16,7 @@
  */
 import { ref, onMounted, watch } from 'vue'
 import { useI18n } from 'vue-i18n'
-import { useDatasource } from '.'
+import { useCustomParams, useDatasource, useResources } from '.'
 import type { IJsonItem } from '../types'
 
 export function useDataX(model: { [field: string]: any }): IJsonItem[] {
@@ -103,6 +103,7 @@ export function useDataX(model: { [field: string]: any }): IJsonItem[] {
   const otherStatementSpan = ref(22)
   const jobSpeedSpan = ref(12)
   const customParameterSpan = ref(0)
+  const useResourcesSpan = ref(0)
 
   const initConstants = () => {
     if (model.customConfig) {
@@ -113,6 +114,7 @@ export function useDataX(model: { [field: string]: any }): IJsonItem[] {
       otherStatementSpan.value = 0
       jobSpeedSpan.value = 0
       customParameterSpan.value = 24
+      useResourcesSpan.value = 24
     } else {
       sqlEditorSpan.value = 24
       jsonEditorSpan.value = 0
@@ -121,9 +123,17 @@ export function useDataX(model: { [field: string]: any }): IJsonItem[] {
       otherStatementSpan.value = 22
       jobSpeedSpan.value = 12
       customParameterSpan.value = 0
+      useResourcesSpan.value = 0
     }
   }
-
+  const supportedDatasourceType = [
+    'MYSQL',
+    'POSTGRESQL',
+    'ORACLE',
+    'SQLSERVER',
+    'CLICKHOUSE',
+    'HIVE'
+  ]
   onMounted(() => {
     initConstants()
   })
@@ -143,7 +153,8 @@ export function useDataX(model: { [field: string]: any }): IJsonItem[] {
     ...useDatasource(model, {
       typeField: 'dsType',
       sourceField: 'dataSource',
-      span: datasourceSpan
+      span: datasourceSpan,
+      supportedDatasourceType
     }),
     {
       type: 'editor',
@@ -167,10 +178,12 @@ export function useDataX(model: { [field: string]: any }): IJsonItem[] {
         message: t('project.node.sql_empty_tips')
       }
     },
+    useResources(useResourcesSpan),
     ...useDatasource(model, {
       typeField: 'dtType',
       sourceField: 'dataTarget',
-      span: destinationDatasourceSpan
+      span: destinationDatasourceSpan,
+      supportedDatasourceType
     }),
     {
       type: 'input',
@@ -281,6 +294,7 @@ export function useDataX(model: { [field: string]: any }): IJsonItem[] {
       span: 12,
       options: memoryLimitOptions,
       value: 1
-    }
+    },
+    ...useCustomParams({ model, field: 'localParams', isSimple: true })
   ]
 }
