@@ -43,7 +43,9 @@ export function useEmr({
     failRetryTimes: 0,
     workerGroup: 'default',
     delayTime: 0,
-    timeout: 30
+    timeout: 30,
+    programType: 'ADD_JOB_FLOW_STEPS',
+    timeoutNotifyStrategy: ['WARN']
   } as INodeData)
 
   return {
@@ -54,7 +56,7 @@ export function useEmr({
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(),
-      Fields.useEnvironmentName(model, !data?.id),
+      Fields.useEnvironmentName(model, !model.id),
       ...Fields.useTaskGroup(model, projectCode),
       ...Fields.useFailed(),
       Fields.useDelayTime(model),
