@@ -46,7 +46,8 @@ export function useProcedure({
     timeout: 30,
     type: data?.taskParams?.type ? data?.taskParams?.type : 'MYSQL',
     datasource: data?.taskParams?.datasource,
-    method: data?.taskParams?.method
+    method: data?.taskParams?.method,
+    timeoutNotifyStrategy: ['WARN']
   } as INodeData)
 
   return {
@@ -57,7 +58,7 @@ export function useProcedure({
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(),
-      Fields.useEnvironmentName(model, !data?.id),
+      Fields.useEnvironmentName(model, !model.id),
       ...Fields.useTaskGroup(model, projectCode),
       ...Fields.useFailed(),
       Fields.useDelayTime(model),
