@@ -51,7 +51,8 @@ export function useSql({
     sqlType: '0',
     preStatements: [],
     postStatements: [],
-    udfs: []
+    udfs: [],
+    timeoutNotifyStrategy: ['WARN']
   } as INodeData)
 
   return {
@@ -62,7 +63,7 @@ export function useSql({
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(),
-      Fields.useEnvironmentName(model, !data?.id),
+      Fields.useEnvironmentName(model, !model.id),
       ...Fields.useTaskGroup(model, projectCode),
       ...Fields.useFailed(),
       Fields.useDelayTime(model),
