@@ -42,7 +42,8 @@ export function useZeppelin({
     failRetryTimes: 0,
     workerGroup: 'default',
     delayTime: 0,
-    timeout: 30
+    timeout: 30,
+    timeoutNotifyStrategy: ['WARN']
   } as INodeData)
 
   return {
@@ -53,7 +54,7 @@ export function useZeppelin({
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(),
-      Fields.useEnvironmentName(model, !data?.id),
+      Fields.useEnvironmentName(model, !model.id),
       ...Fields.useTaskGroup(model, projectCode),
       ...Fields.useFailed(),
       Fields.useDelayTime(model),
