@@ -17,45 +17,50 @@
 
 package org.apache.dolphinscheduler.server.worker.config;
 
+import static org.apache.dolphinscheduler.common.constants.Constants.REGISTRY_DOLPHINSCHEDULER_WORKERS;
+
 import org.apache.dolphinscheduler.common.utils.NetUtils;
+import org.apache.dolphinscheduler.registry.api.ConnectStrategyProperties;
 
 import java.time.Duration;
-import java.util.Set;
 
+import lombok.Data;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 import org.springframework.context.annotation.Configuration;
 import org.springframework.validation.Errors;
 import org.springframework.validation.Validator;
 import org.springframework.validation.annotation.Validated;
 
-import com.google.common.collect.Sets;
-
-import lombok.Data;
-
 @Data
 @Validated
 @Configuration
 @ConfigurationProperties(prefix = "worker")
 public class WorkerConfig implements Validator {
+
+    private Logger logger = LoggerFactory.getLogger(WorkerConfig.class);
+
     private int listenPort = 1234;
     private int execThreads = 10;
     private Duration heartbeatInterval = Duration.ofSeconds(10);
-    /**
-     * Worker heart beat task error threshold, if the continuous error count exceed this count, the worker will close.
-     */
-    private int heartbeatErrorThreshold = 5;
     private int hostWeight = 100;
     private boolean tenantAutoCreate = true;
     private boolean tenantDistributedUser = false;
     private int maxCpuLoadAvg = -1;
     private double reservedMemory = 0.3;
-    private Set<String> groups = Sets.newHashSet("default");
     private String alertListenHost = "localhost";
     private int alertListenPort = 50052;
+    private ConnectStrategyProperties registryDisconnectStrategy = new ConnectStrategyProperties();
+
     /**
      * This field doesn't need to set at config file, it will be calculated by workerIp:listenPort
      */
     private String workerAddress;
+    private String workerRegistryPath;
+
+    private TaskExecuteThreadsFullPolicy taskExecuteThreadsFullPolicy = TaskExecuteThreadsFullPolicy.REJECT;
 
     @Override
     public boolean supports(Class<?> clazz) {
@@ -74,9 +79,26 @@ public class WorkerConfig implements Validator {
         if (workerConfig.getMaxCpuLoadAvg() <= 0) {
             workerConfig.setMaxCpuLoadAvg(Runtime.getRuntime().availableProcessors() * 2);
         }
-        if (workerConfig.getHeartbeatErrorThreshold() <= 0) {
-            errors.rejectValue("heartbeat-error-threshold", null, "should be a positive value");
-        }
         workerConfig.setWorkerAddress(NetUtils.getAddr(workerConfig.getListenPort()));
+
+        workerConfig.setWorkerRegistryPath(REGISTRY_DOLPHINSCHEDULER_WORKERS + "/" + workerConfig.getWorkerAddress());
+        printConfig();
+    }
+
+    private void printConfig() {
+        logger.info("Worker config: listenPort -> {}", listenPort);
+        logger.info("Worker config: execThreads -> {}", execThreads);
+        logger.info("Worker config: heartbeatInterval -> {}", heartbeatInterval);
+        logger.info("Worker config: hostWeight -> {}", hostWeight);
+        logger.info("Worker config: tenantAutoCreate -> {}", tenantAutoCreate);
+        logger.info("Worker config: tenantDistributedUser -> {}", tenantDistributedUser);
+        logger.info("Worker config: maxCpuLoadAvg -> {}", maxCpuLoadAvg);
+        logger.info("Worker config: reservedMemory -> {}", reservedMemory);
+        logger.info("Worker config: alertListenHost -> {}", alertListenHost);
+        logger.info("Worker config: alertListenPort -> {}", alertListenPort);
+        logger.info("Worker config: registryDisconnectStrategy -> {}", registryDisconnectStrategy);
+        logger.info("Worker config: workerAddress -> {}", registryDisconnectStrategy);
+        logger.info("Worker config: workerRegistryPath: {}", workerRegistryPath);
+        logger.info("Worker config: taskExecuteThreadsFullPolicy: {}", taskExecuteThreadsFullPolicy);
     }
 }
